@@ -182,10 +182,6 @@ class VAP200( _vap ):
     def getSensorPower( self ):
         return int(self.daq( 'pwr_s' )[0])
 
-    # to be obseleted, only for debug
-    def setExtendPower( self, on=True ):
-        self.daq( 'pwr_e', value=int(bool(on)) )
-
     def setSpeedBitmap( self, bitmap=0x00 ):
         self.daq( 'speed', value=bitmap )
     
@@ -253,6 +249,16 @@ class VAP200( _vap ):
                 ret[idx] = {'offset': avg, 'rms': rms}
         return ret
          
+    def getExtVoltage(self):
+        return [float(l.split()[1]) for l in self.writeCommand('ext')]
+ 
+    def setExtAlarmOutput( self, on=True ):
+        self.daq( 'pwr_e', value=int(bool(on)) )
+
+    def getExtAlarmOutput( self ):
+        return int(self.daq( 'pwr_e' )[0])
+
+
 
 class VAP200Extend( Mcush.Mcush ):
     '''VAP200 Extend Boards'''
@@ -269,9 +275,9 @@ class VAP200Extend( Mcush.Mcush ):
             command += ' -v %d'% value
         return self.writeCommand( command )
      
-    def getValue(self):
+    def getVoltage(self):
         return [float(l.split()[1]) for l in self.measure()]
-        
+
 
 #############################################################################
 # MODBUS TCP CLIENT
@@ -324,6 +330,17 @@ REG_LOCAL_THRESHOLD_MV_4    = 64
 REG_LOCAL_THRESHOLD_MV_5    = 65
 REG_LOCAL_THRESHOLD_MV_6    = 66
 REG_LOCAL_THRESHOLD_MV_7    = 67
+# extend board group
+REG_EXTEND_EXIST            = 100
+REG_EXTEND_ALARM_OUTPUT     = 101
+REG_EXTEND_MV_0             = 102
+REG_EXTEND_MV_1             = 103
+REG_EXTEND_MV_2             = 104
+REG_EXTEND_MV_3             = 105
+REG_EXTEND_MV_4             = 106
+REG_EXTEND_MV_5             = 107
+REG_EXTEND_MV_6             = 108
+REG_EXTEND_MV_7             = 109
 
 # waveform buffer mapping
 REG_BUFFER_BEGIN        = 10000
@@ -467,7 +484,21 @@ class VAP200_ModbusTCP( McushModbusTCP ):
                 dat.append( _process_vap200_adc_val(self, channel, i, adc, False) )
         return dat
 
+    def getExtVoltage(self):
+        # return extend board voltage, if board does not exist, return empty list
+        if not self.readReg(REG_EXTEND_EXIST):
+            return []
+        regs = self.readRegs(REG_EXTEND_MV_0, 8)
+        return [r/1000.0 for r in regs]
+ 
+    def setExtAlarmOutput( self, on=True ):
+        self.writeReg( REG_EXTEND_ALARM_OUTPUT, int(bool(on)) )
 
+    def getExtAlarmOutput( self ):
+        return bool(self.readReg(REG_EXTEND_ALARM_OUTPUT))
+
+
+ 
 #############################################################################
 # MQTT CLIENT
 
@@ -725,5 +756,15 @@ class VAP200_MQTT():
     def rtcRead( self ): 
         return self.publishCmd( 'rtc', check_reply=True )['V']
 
+    def getExtVoltage(self):
+        # return extend board voltage, if board not exists, return empty list
+        return []
+ 
+    def setExtAlarmOutput( self, on=True ):
+        self.publishCmd( 'ext_alarm', val=int(on) ) 
+
+    def getExtAlarmOutput( self ):
+        return self.publishCmd( 'ext_alarm', check_reply=True )['V']
+
 
 
